@@ -28,6 +28,20 @@ class Client:
         if isinstance(res, dict):
             return res['data']['expire_time']
         return res
+    
+
+    def get_proxy_authorization(self, plain_text=0, sign_type="simple"):
+        """获取指定订单访问代理IP的鉴权信息。
+        鉴权信息包含用户名密码，用于请求私密代理/独享代理/隧道代理时进行身份验证。
+            :return 返回信息的字典
+        """
+        endpoint = EndPoint.GetProxyAuthorization.value
+        params = self._get_params(endpoint,plaintext=plain_text,sign_type=sign_type)
+        res = self._get_base_res("GET", endpoint, params)
+        if isinstance(res, dict):
+            return res['data']
+        return res
+
 
     def get_ip_whitelist(self, sign_type="simple"):
         """获取订单的ip白名单, 强制签名验证
